==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/RegistrationDetails.java <==
package com.example.model;

/**
 * Model for RegistrationDetails
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "RegistrationDetails", description = "Model for RegistrationDetails")
@javax.xml.bind.annotation.XmlRootElement(name = "RegistrationDetails")
public class RegistrationDetails implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String label = null;
	private java.lang.String value = null;
	
	/**
	 */
	public RegistrationDetails label(java.lang.String label) {
		setLabel(label);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("label")
	@javax.validation.constraints.NotNull
	public java.lang.String getLabel() {
		return this.label;
	}
	public void setLabel(java.lang.String label) {
		this.label = label;
	}
	
	/**
	 */
	public RegistrationDetails value(java.lang.String value) {
		setValue(value);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("value")
	public java.lang.String getValue() {
		return this.value;
	}
	public void setValue(java.lang.String value) {
		this.value = value;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		RegistrationDetails registrationDetails = (RegistrationDetails) o;
		return java.util.Objects.equals(this.label, registrationDetails.label)
				&& java.util.Objects.equals(this.value, registrationDetails.value);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.label, this.value);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class RegistrationDetails {\n");
		
		sb.append("    label: ").append(toIndentedString(this.label)).append("\n");
		sb.append("    value: ").append(toIndentedString(this.value)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/RegistrationDetails.java <==
package com.example.model;

/**
 * Model for RegistrationDetails
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "RegistrationDetails", description = "Model for RegistrationDetails")
@javax.xml.bind.annotation.XmlRootElement(name = "RegistrationDetails")
public class RegistrationDetails implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String label = null;
	private java.lang.String value = null;
	
	/**
	 */
	public RegistrationDetails label(java.lang.String label) {
		setLabel(label);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "label")
	@com.fasterxml.jackson.annotation.JsonProperty("label")
	@javax.validation.constraints.NotNull
	public java.lang.String getLabel() {
		return this.label;
	}
	public void setLabel(java.lang.String label) {
		this.label = label;
	}
	
	/**
	 */
	public RegistrationDetails value(java.lang.String value) {
		setValue(value);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "value")
	@com.fasterxml.jackson.annotation.JsonProperty("value")
	public java.lang.String getValue() {
		return this.value;
	}
	public void setValue(java.lang.String value) {
		this.value = value;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		RegistrationDetails registrationDetails = (RegistrationDetails) o;
		return java.util.Objects.equals(this.label, registrationDetails.label)
				&& java.util.Objects.equals(this.value, registrationDetails.value);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.label, this.value);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class RegistrationDetails {\n");
		
		sb.append("    label: ").append(toIndentedString(this.label)).append("\n");
		sb.append("    value: ").append(toIndentedString(this.value)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
